/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct RootObj RootObj;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__PJMRIt5QxCm6bRaVyQ5CGA tySequence__PJMRIt5QxCm6bRaVyQ5CGA;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tySequence__YWbgnI9b9a4j9aDYnupShIg3A tySequence__YWbgnI9b9a4j9aDYnupShIg3A;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg;
typedef struct tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ;
typedef struct tySequence__JokFGfUW6i9b6aeU7xu6xBw tySequence__JokFGfUW6i9b6aeU7xu6xBw;
typedef struct tyTuple__SlmU1Ju0WFHUWkihyHMVYg tyTuple__SlmU1Ju0WFHUWkihyHMVYg;
typedef struct tyObject_TBlock__2tJGcW69ahqq39a9bVJC1sqGQ tyObject_TBlock__2tJGcW69ahqq39a9bVJC1sqGQ;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tyTuple__C1iPjdrPjiQaUrcFhIp9aGw tyTuple__C1iPjdrPjiQaUrcFhIp9aGw;
typedef struct tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA;
typedef struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A tyTuple__JfHvHzMrhKkWAUvQKe0i1A;
typedef struct tyObject_Env_vmdefdotnim_vmdef___diB2NTuAIWY0FO9c5IUJRGg tyObject_Env_vmdefdotnim_vmdef___diB2NTuAIWY0FO9c5IUJRGg;
typedef struct tySequence__jlXqfsdfoRhiIfoVNWV0Vw tySequence__jlXqfsdfoRhiIfoVNWV0Vw;
typedef struct tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w {
  RootObj Sup;
};
typedef NU8 tyEnum_TEvalMode__UbrbHUpo4hYFr1DbYzJgRQ;
typedef NU8 tySet_tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg {
NF tEnter;
tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ* tos;
};
struct tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw {
  tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w Sup;
tySequence__YdLNCDKYeipzJx3I8Xw82Q* code;
tySequence__PJMRIt5QxCm6bRaVyQ5CGA* debug;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* globals;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constants;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* types;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* currentExceptionA;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* currentExceptionB;
NI exceptionInstr;
tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ* prc;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* callsite;
tyEnum_TEvalMode__UbrbHUpo4hYFr1DbYzJgRQ mode;
tySet_tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A features;
NIM_BOOL traceActive;
NI loopIterations;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q comesFromHeuristic;
tySequence__YWbgnI9b9a4j9aDYnupShIg3A* callbacks;
NimStringDesc* errorFlag;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
NI oldErrorCount;
tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg profiler;
NI* templInstCounter;
};
typedef NU8 tyEnum_TSlotKind__QOyrDzzey9cf6gDtSRPuZMQ;
struct tyTuple__SlmU1Ju0WFHUWkihyHMVYg {
NIM_BOOL Field0;
tyEnum_TSlotKind__QOyrDzzey9cf6gDtSRPuZMQ Field1;
};
typedef tyTuple__SlmU1Ju0WFHUWkihyHMVYg tyArray__EYsuRBqqo81SUrCUzYSAKA[65536];
struct tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ {
tySequence__JokFGfUW6i9b6aeU7xu6xBw* blocks;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__EYsuRBqqo81SUrCUzYSAKA slots;
NI maxSlots;
};
struct tyObject_TBlock__2tJGcW69ahqq39a9bVJC1sqGQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* label;
tySequence__qwqHTkRvwhrRyENtudHQ7g* fixups;
};
typedef NU8 tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA* args, void* ClE_0);
void* ClE_0;
} tyProc__5QC9cKfPJmKuW0XbCTd8ylA;
struct tyTuple__C1iPjdrPjiQaUrcFhIp9aGw {
NimStringDesc* Field0;
tyProc__5QC9cKfPJmKuW0XbCTd8ylA Field1;
};
struct tyTuple__JfHvHzMrhKkWAUvQKe0i1A {
void* Field0;
tyObject_Env_vmdefdotnim_vmdef___diB2NTuAIWY0FO9c5IUJRGg* Field1;
};
struct tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ {
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc;
tySequence__jlXqfsdfoRhiIfoVNWV0Vw* slots;
tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ* next;
NI comesFrom;
tySequence__qwqHTkRvwhrRyENtudHQ7g* safePoints;
};
typedef NU8 tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ;
struct tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA {
tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ kind;
union{
NI64 intVal;
NF floatVal;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* node;
tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA* regAddr;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** nodeAddr;
};
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct tyObject_VmArgs__0UUl6e5CNNQfMon2xW2bVA {
NI ra;
NI rb;
NI rc;
tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA* slots;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* currentException;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q currentLineInfo;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  TGenericSeq Sup;
  NU64 data[SEQ_DECL_SIZE];
};
struct tySequence__PJMRIt5QxCm6bRaVyQ5CGA {
  TGenericSeq Sup;
  tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  TGenericSeq Sup;
  NI data[SEQ_DECL_SIZE];
};
struct tySequence__JokFGfUW6i9b6aeU7xu6xBw {
  TGenericSeq Sup;
  tyObject_TBlock__2tJGcW69ahqq39a9bVJC1sqGQ data[SEQ_DECL_SIZE];
};
struct tySequence__YWbgnI9b9a4j9aDYnupShIg3A {
  TGenericSeq Sup;
  tyTuple__C1iPjdrPjiQaUrcFhIp9aGw data[SEQ_DECL_SIZE];
};
struct tySequence__jlXqfsdfoRhiIfoVNWV0Vw {
  TGenericSeq Sup;
  tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_NIMCALL(void, Marker_tySequence__YdLNCDKYeipzJx3I8Xw82Q)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__PJMRIt5QxCm6bRaVyQ5CGA)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__qwqHTkRvwhrRyENtudHQ7g)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__JokFGfUW6i9b6aeU7xu6xBw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__FM7mzTFsA8pyUhXVKKO6Gw)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__YWbgnI9b9a4j9aDYnupShIg3A)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__jlXqfsdfoRhiIfoVNWV0Vw)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__tIxM6OLoE2pUc9bMTjYhjPg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__FD9cVFUpCDGxUmwW7TEZIFQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(void, nimGCunrefRC1)(void* p);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);

/* section: NIM_merge_DATA */
extern TNimType NTI__Hb6rFM0ecvtlLf2kv9aU75w_;
N_LIB_PRIVATE TNimType NTI__S3Av1Ng7MBWGEZZBhfDYCw_;
N_LIB_PRIVATE TNimType NTI__wMtfD88jmrPZwfzTH9c8e9cA_;
N_LIB_PRIVATE TNimType NTI__YdLNCDKYeipzJx3I8Xw82Q_;
extern TNimType NTI__WGx4rAexNXnczy1Avn646Q_;
N_LIB_PRIVATE TNimType NTI__PJMRIt5QxCm6bRaVyQ5CGA_;
extern TNimType NTI__fKfcLzXYiz5jNu3NH3Tv8Q_;
extern TNimType NTI__Ef05srmQTDulnBdXR4Ja6Q_;
extern TNimType NTI__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTI__VFEBuxrDHC6kHPzc1TWaRQ_;
N_LIB_PRIVATE TNimType NTI__2tJGcW69ahqq39a9bVJC1sqGQ_;
extern TNimType NTI__K9bspPztfoWajecnwjyHuYQ_;
N_LIB_PRIVATE TNimType NTI__qwqHTkRvwhrRyENtudHQ7g_;
N_LIB_PRIVATE TNimType NTI__JokFGfUW6i9b6aeU7xu6xBw_;
N_LIB_PRIVATE TNimType NTI__SlmU1Ju0WFHUWkihyHMVYg_;
extern TNimType NTI__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTI__QOyrDzzey9cf6gDtSRPuZMQ_;
N_LIB_PRIVATE TNimType NTI__EYsuRBqqo81SUrCUzYSAKA_;
N_LIB_PRIVATE TNimType NTI__FM7mzTFsA8pyUhXVKKO6Gw_;
N_LIB_PRIVATE TNimType NTI__UbrbHUpo4hYFr1DbYzJgRQ_;
N_LIB_PRIVATE TNimType NTI__JyPEhkAmDAldmLHNNrLR0A_;
N_LIB_PRIVATE TNimType NTI__sOguoHO9bh9ckVU25A2Jaz1A_;
N_LIB_PRIVATE TNimType NTI__C1iPjdrPjiQaUrcFhIp9aGw_;
extern TNimType NTI__77mFvmsOLKik79ci2hXkHEg_;
N_LIB_PRIVATE TNimType NTI__5QC9cKfPJmKuW0XbCTd8ylA_;
extern TNimType NTI__vr5DoT1jILTGdRlYv1OYpw_;
extern TNimType NTI__HsJiUUcO9cHBdUCi0HwkSTA_;
N_LIB_PRIVATE TNimType NTI__YWbgnI9b9a4j9aDYnupShIg3A_;
extern TNimType NTI__lnkYNZP9asc88UfiEGjLrbA_;
extern TNimType NTI__a8lycfSA25OQltN3OMeBsA_;
extern TNimType NTI__KfdHSsl8vyUCSI9b3inBcww_;
N_LIB_PRIVATE TNimType NTI__X5SfC6PDEhDFna4qLF0vtg_;
extern TNimType NTI__w9bl9a1ul9ctRJWiMl9cNnIMvg_;
N_LIB_PRIVATE TNimType NTI__DYXeymOyKb0OnIuD1ihEpQ_;
N_LIB_PRIVATE TNimType NTI__GJRDbRqzZnSsmt2gZMzKBA_;
N_LIB_PRIVATE TNimType NTI__BUH8cfx9botv2xAfmC8mnAQ_;
TNimNode* NimDT___GJRDbRqzZnSsmt2gZMzKBA_kind[7];
extern TNimType NTI__Aav8dQoMlCFnZRxA0IhTHQ_;
N_LIB_PRIVATE TNimType NTI__RjjpIF1Vbh8mUcjJMFLQMA_;
extern TNimType NTI__uyBDtVkS7CL1Bm1j1dvmcw_;
N_LIB_PRIVATE TNimType NTI__jlXqfsdfoRhiIfoVNWV0Vw_;
N_LIB_PRIVATE TNimType NTI__tIxM6OLoE2pUc9bMTjYhjPg_;
extern TNimType NTI__9ai78kkwqt3gikTN9cpHKUVg_;
N_LIB_PRIVATE TNimType NTI__FD9cVFUpCDGxUmwW7TEZIFQ_;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_NIMCALL(void, Marker_tySequence__YdLNCDKYeipzJx3I8Xw82Q)(void* p, NI op) {
	tySequence__YdLNCDKYeipzJx3I8Xw82Q* a;
	NI T1_;
	a = (tySequence__YdLNCDKYeipzJx3I8Xw82Q*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__PJMRIt5QxCm6bRaVyQ5CGA)(void* p, NI op) {
	tySequence__PJMRIt5QxCm6bRaVyQ5CGA* a;
	NI T1_;
	a = (tySequence__PJMRIt5QxCm6bRaVyQ5CGA*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__qwqHTkRvwhrRyENtudHQ7g)(void* p, NI op) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* a;
	NI T1_;
	a = (tySequence__qwqHTkRvwhrRyENtudHQ7g*)p;
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__JokFGfUW6i9b6aeU7xu6xBw)(void* p, NI op) {
	tySequence__JokFGfUW6i9b6aeU7xu6xBw* a;
	NI T1_;
	a = (tySequence__JokFGfUW6i9b6aeU7xu6xBw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].label, op);
	nimGCvisit((void*)a->data[T1_].fixups, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__FM7mzTFsA8pyUhXVKKO6Gw)(void* p, NI op) {
	tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ* a;
	NI T1_;
	a = (tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ*)p;
	nimGCvisit((void*)(*a).blocks, op);
	nimGCvisit((void*)(*a).sym, op);
	T1_ = (NI)0;
}
static N_NIMCALL(void, Marker_tySequence__YWbgnI9b9a4j9aDYnupShIg3A)(void* p, NI op) {
	tySequence__YWbgnI9b9a4j9aDYnupShIg3A* a;
	NI T1_;
	a = (tySequence__YWbgnI9b9a4j9aDYnupShIg3A*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field0, op);
	nimGCvisit((void*)a->data[T1_].Field1.ClE_0, op);
	}
}
static N_NIMCALL(void, Marker_tySequence__jlXqfsdfoRhiIfoVNWV0Vw)(void* p, NI op) {
	tySequence__jlXqfsdfoRhiIfoVNWV0Vw* a;
	NI T1_;
	a = (tySequence__jlXqfsdfoRhiIfoVNWV0Vw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	switch (a->data[T1_].kind) {
	case ((tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ) 0):
	break;
	case ((tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ) 2):
	break;
	case ((tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ) 3):
	break;
	case ((tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ) 1):
	nimGCvisit((void*)a->data[T1_].node, op);
	break;
	case ((tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ) 4):
	break;
	case ((tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ) 5):
	break;
	} 
	}
}
static N_NIMCALL(void, Marker_tyRef__tIxM6OLoE2pUc9bMTjYhjPg)(void* p, NI op) {
	tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ* a;
	a = (tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ*)p;
	nimGCvisit((void*)(*a).prc, op);
	nimGCvisit((void*)(*a).slots, op);
	nimGCvisit((void*)(*a).next, op);
	nimGCvisit((void*)(*a).safePoints, op);
}
static N_NIMCALL(void, Marker_tyRef__FD9cVFUpCDGxUmwW7TEZIFQ)(void* p, NI op) {
	tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* a;
	a = (tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*)p;
	nimGCvisit((void*)(*a).code, op);
	nimGCvisit((void*)(*a).debug, op);
	nimGCvisit((void*)(*a).globals, op);
	nimGCvisit((void*)(*a).constants, op);
	nimGCvisit((void*)(*a).types, op);
	nimGCvisit((void*)(*a).currentExceptionA, op);
	nimGCvisit((void*)(*a).currentExceptionB, op);
	nimGCvisit((void*)(*a).prc, op);
	nimGCvisit((void*)(*a).module, op);
	nimGCvisit((void*)(*a).callsite, op);
	nimGCvisit((void*)(*a).callbacks, op);
	nimGCvisit((void*)(*a).errorFlag, op);
	nimGCvisit((void*)(*a).cache, op);
	nimGCvisit((void*)(*a).config, op);
	nimGCvisit((void*)(*a).graph, op);
	nimGCvisit((void*)(*a).profiler.tos, op);
	nimGCvisit((void*)(*a).templInstCounter, op);
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefRC1)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*, newCtx__SnMRNFK9aeDXTXGWpZkzETw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g) {
	tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* result;
	tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* T1_;
	tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ* T2_;
	result = (tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*)0;
	T1_ = (tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*)0;
	T1_ = (tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*) newObj((&NTI__FD9cVFUpCDGxUmwW7TEZIFQ_), sizeof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw));
	(*T1_).Sup.Sup.m_type = (&NTI__S3Av1Ng7MBWGEZZBhfDYCw_);
	if ((*T1_).code) { nimGCunrefNoCycle((*T1_).code); (*T1_).code = NIM_NIL; }
	if ((*T1_).debug) { nimGCunrefNoCycle((*T1_).debug); (*T1_).debug = NIM_NIL; }
	asgnRef((void**) (&(*T1_).globals), newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126)));
	asgnRef((void**) (&(*T1_).constants), newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115)));
	if ((*T1_).types) { nimGCunrefNoCycle((*T1_).types); (*T1_).types = NIM_NIL; }
	T2_ = (tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ*)0;
	T2_ = (tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ*) newObj((&NTI__FM7mzTFsA8pyUhXVKKO6Gw_), sizeof(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ));
	if ((*T2_).blocks) { nimGCunrefNoCycle((*T2_).blocks); (*T2_).blocks = NIM_NIL; }
	asgnRef((void**) (&(*T1_).prc), T2_);
	asgnRef((void**) (&(*T1_).module), module);
	(*T1_).loopIterations = (*(*g).config).maxLoopIterationsVM;
	(*T1_).comesFromHeuristic = unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
	if ((*T1_).callbacks) { nimGCunrefRC1((*T1_).callbacks); (*T1_).callbacks = NIM_NIL; }
	asgnRef((void**) (&(*T1_).errorFlag), ((NimStringDesc*) NIM_NIL));
	asgnRef((void**) (&(*T1_).cache), cache);
	asgnRef((void**) (&(*T1_).config), (*g).config);
	asgnRef((void**) (&(*T1_).graph), g);
	result = T1_;
	return result;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(NI, registerCallback__KnNoqgKj9bmG2p3f4SLNFqA)(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* c, NimStringDesc* name, tyProc__5QC9cKfPJmKuW0XbCTd8ylA callback) {
	NI result;
	NI T1_;
	tyTuple__C1iPjdrPjiQaUrcFhIp9aGw T2_;
	NI T3_;
	NimStringDesc* T4_;
	result = (NI)0;
	T1_ = ((*c).callbacks ? (*c).callbacks->Sup.len : 0);
	result = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__C1iPjdrPjiQaUrcFhIp9aGw));
	T2_.Field0 = copyString(name);
	T2_.Field1.ClE_0 = callback.ClE_0;
	T2_.Field1.ClP_0 = callback.ClP_0;
	asgnRef((void**) (&(*c).callbacks), (tySequence__YWbgnI9b9a4j9aDYnupShIg3A*) incrSeqV3((TGenericSeq*)((*c).callbacks), (&NTI__YWbgnI9b9a4j9aDYnupShIg3A_)));
	T3_ = (*c).callbacks->Sup.len++;
	T4_ = (NimStringDesc*)0;
	T4_ = (*c).callbacks->data[T3_].Field0; (*c).callbacks->data[T3_].Field0 = copyStringRC1(T2_.Field0);
	if (T4_) nimGCunrefNoCycle(T4_);
	asgnRef((void**) (&(*c).callbacks->data[T3_].Field1.ClE_0), T2_.Field1.ClE_0);
	(*c).callbacks->data[T3_].Field1.ClP_0 = T2_.Field1.ClP_0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, refresh__VN2MrcCIq6xPNBFBZXkK1Q)(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module) {
	tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ* T1_;
	asgnRef((void**) (&(*c).module), module);
	T1_ = (tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ*)0;
	T1_ = (tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ*) newObj((&NTI__FM7mzTFsA8pyUhXVKKO6Gw_), sizeof(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ));
	if ((*T1_).blocks) { nimGCunrefNoCycle((*T1_).blocks); (*T1_).blocks = NIM_NIL; }
	asgnRef((void**) (&(*c).prc), T1_);
	(*c).loopIterations = (*(*c).config).maxLoopIterationsVM;
}
N_LIB_PRIVATE N_NIMCALL(void, compiler_vmdefDatInit000)(void) {

/* section: NIM_merge_TYPE_INIT1 */
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_2_24[24];
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_3_4[4];
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_4_2[2];
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_5_2[2];
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_6_9[9];
NI TM__LKTmeQxNOMAggl6ESLJFSg_8;
static char* NIM_CONST TM__LKTmeQxNOMAggl6ESLJFSg_7[9] = {
"slotEmpty", 
"slotFixedVar", 
"slotFixedLet", 
"slotTempUnknown", 
"slotTempInt", 
"slotTempFloat", 
"slotTempStr", 
"slotTempComplex", 
"slotTempPerm"};
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_9_5[5];
NI TM__LKTmeQxNOMAggl6ESLJFSg_11;
static char* NIM_CONST TM__LKTmeQxNOMAggl6ESLJFSg_10[5] = {
"emRepl", 
"emConst", 
"emOptimize", 
"emStaticExpr", 
"emStaticStmt"};
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_12_2[2];
NI TM__LKTmeQxNOMAggl6ESLJFSg_14;
static char* NIM_CONST TM__LKTmeQxNOMAggl6ESLJFSg_13[2] = {
"allowCast", 
"allowInfiniteLoops"};
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_15_2[2];
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_16_2[2];
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_17_2[2];
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_18_5[5];
static TNimNode* TM__LKTmeQxNOMAggl6ESLJFSg_19_6[6];
NI TM__LKTmeQxNOMAggl6ESLJFSg_21;
static char* NIM_CONST TM__LKTmeQxNOMAggl6ESLJFSg_20[6] = {
"rkNone", 
"rkNode", 
"rkInt", 
"rkFloat", 
"rkRegisterAddr", 
"rkNodeAddr"};
static TNimNode TM__LKTmeQxNOMAggl6ESLJFSg_0[85];

/* section: NIM_merge_TYPE_INIT3 */
NTI__S3Av1Ng7MBWGEZZBhfDYCw_.size = sizeof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw);
NTI__S3Av1Ng7MBWGEZZBhfDYCw_.align = NIM_ALIGNOF(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw);
NTI__S3Av1Ng7MBWGEZZBhfDYCw_.kind = 17;
NTI__S3Av1Ng7MBWGEZZBhfDYCw_.base = (&NTI__Hb6rFM0ecvtlLf2kv9aU75w_);
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[1];
NTI__wMtfD88jmrPZwfzTH9c8e9cA_.size = sizeof(NU64);
NTI__wMtfD88jmrPZwfzTH9c8e9cA_.align = NIM_ALIGNOF(NU64);
NTI__wMtfD88jmrPZwfzTH9c8e9cA_.kind = 44;
NTI__wMtfD88jmrPZwfzTH9c8e9cA_.base = 0;
NTI__wMtfD88jmrPZwfzTH9c8e9cA_.flags = 3;
NTI__YdLNCDKYeipzJx3I8Xw82Q_.size = sizeof(tySequence__YdLNCDKYeipzJx3I8Xw82Q*);
NTI__YdLNCDKYeipzJx3I8Xw82Q_.align = NIM_ALIGNOF(tySequence__YdLNCDKYeipzJx3I8Xw82Q*);
NTI__YdLNCDKYeipzJx3I8Xw82Q_.kind = 24;
NTI__YdLNCDKYeipzJx3I8Xw82Q_.base = (&NTI__wMtfD88jmrPZwfzTH9c8e9cA_);
NTI__YdLNCDKYeipzJx3I8Xw82Q_.flags = 2;
NTI__YdLNCDKYeipzJx3I8Xw82Q_.marker = Marker_tySequence__YdLNCDKYeipzJx3I8Xw82Q;
TM__LKTmeQxNOMAggl6ESLJFSg_0[1].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[1].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, code);
TM__LKTmeQxNOMAggl6ESLJFSg_0[1].typ = (&NTI__YdLNCDKYeipzJx3I8Xw82Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[1].name = "code";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[2];
NTI__PJMRIt5QxCm6bRaVyQ5CGA_.size = sizeof(tySequence__PJMRIt5QxCm6bRaVyQ5CGA*);
NTI__PJMRIt5QxCm6bRaVyQ5CGA_.align = NIM_ALIGNOF(tySequence__PJMRIt5QxCm6bRaVyQ5CGA*);
NTI__PJMRIt5QxCm6bRaVyQ5CGA_.kind = 24;
NTI__PJMRIt5QxCm6bRaVyQ5CGA_.base = (&NTI__WGx4rAexNXnczy1Avn646Q_);
NTI__PJMRIt5QxCm6bRaVyQ5CGA_.flags = 2;
NTI__PJMRIt5QxCm6bRaVyQ5CGA_.marker = Marker_tySequence__PJMRIt5QxCm6bRaVyQ5CGA;
TM__LKTmeQxNOMAggl6ESLJFSg_0[2].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[2].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, debug);
TM__LKTmeQxNOMAggl6ESLJFSg_0[2].typ = (&NTI__PJMRIt5QxCm6bRaVyQ5CGA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[2].name = "debug";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[2] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[3];
TM__LKTmeQxNOMAggl6ESLJFSg_0[3].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[3].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, globals);
TM__LKTmeQxNOMAggl6ESLJFSg_0[3].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[3].name = "globals";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[3] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[4];
TM__LKTmeQxNOMAggl6ESLJFSg_0[4].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[4].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, constants);
TM__LKTmeQxNOMAggl6ESLJFSg_0[4].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[4].name = "constants";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[4] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[5];
TM__LKTmeQxNOMAggl6ESLJFSg_0[5].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[5].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, types);
TM__LKTmeQxNOMAggl6ESLJFSg_0[5].typ = (&NTI__Ef05srmQTDulnBdXR4Ja6Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[5].name = "types";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[5] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[6];
TM__LKTmeQxNOMAggl6ESLJFSg_0[6].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[6].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, currentExceptionA);
TM__LKTmeQxNOMAggl6ESLJFSg_0[6].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[6].name = "currentExceptionA";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[6] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[7];
TM__LKTmeQxNOMAggl6ESLJFSg_0[7].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[7].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, currentExceptionB);
TM__LKTmeQxNOMAggl6ESLJFSg_0[7].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[7].name = "currentExceptionB";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[7] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[8];
TM__LKTmeQxNOMAggl6ESLJFSg_0[8].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[8].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, exceptionInstr);
TM__LKTmeQxNOMAggl6ESLJFSg_0[8].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[8].name = "exceptionInstr";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[8] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[9];
NTI__VFEBuxrDHC6kHPzc1TWaRQ_.size = sizeof(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ);
NTI__VFEBuxrDHC6kHPzc1TWaRQ_.align = NIM_ALIGNOF(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ);
NTI__VFEBuxrDHC6kHPzc1TWaRQ_.kind = 18;
NTI__VFEBuxrDHC6kHPzc1TWaRQ_.base = 0;
NTI__VFEBuxrDHC6kHPzc1TWaRQ_.flags = 2;
TM__LKTmeQxNOMAggl6ESLJFSg_3_4[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[11];
NTI__2tJGcW69ahqq39a9bVJC1sqGQ_.size = sizeof(tyObject_TBlock__2tJGcW69ahqq39a9bVJC1sqGQ);
NTI__2tJGcW69ahqq39a9bVJC1sqGQ_.align = NIM_ALIGNOF(tyObject_TBlock__2tJGcW69ahqq39a9bVJC1sqGQ);
NTI__2tJGcW69ahqq39a9bVJC1sqGQ_.kind = 18;
NTI__2tJGcW69ahqq39a9bVJC1sqGQ_.base = 0;
NTI__2tJGcW69ahqq39a9bVJC1sqGQ_.flags = 2;
TM__LKTmeQxNOMAggl6ESLJFSg_4_2[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[13];
TM__LKTmeQxNOMAggl6ESLJFSg_0[13].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[13].offset = offsetof(tyObject_TBlock__2tJGcW69ahqq39a9bVJC1sqGQ, label);
TM__LKTmeQxNOMAggl6ESLJFSg_0[13].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[13].name = "label";
TM__LKTmeQxNOMAggl6ESLJFSg_4_2[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[14];
NTI__qwqHTkRvwhrRyENtudHQ7g_.size = sizeof(tySequence__qwqHTkRvwhrRyENtudHQ7g*);
NTI__qwqHTkRvwhrRyENtudHQ7g_.align = NIM_ALIGNOF(tySequence__qwqHTkRvwhrRyENtudHQ7g*);
NTI__qwqHTkRvwhrRyENtudHQ7g_.kind = 24;
NTI__qwqHTkRvwhrRyENtudHQ7g_.base = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
NTI__qwqHTkRvwhrRyENtudHQ7g_.flags = 2;
NTI__qwqHTkRvwhrRyENtudHQ7g_.marker = Marker_tySequence__qwqHTkRvwhrRyENtudHQ7g;
TM__LKTmeQxNOMAggl6ESLJFSg_0[14].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[14].offset = offsetof(tyObject_TBlock__2tJGcW69ahqq39a9bVJC1sqGQ, fixups);
TM__LKTmeQxNOMAggl6ESLJFSg_0[14].typ = (&NTI__qwqHTkRvwhrRyENtudHQ7g_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[14].name = "fixups";
TM__LKTmeQxNOMAggl6ESLJFSg_0[12].len = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[12].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[12].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_4_2[0];
NTI__2tJGcW69ahqq39a9bVJC1sqGQ_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[12];
NTI__JokFGfUW6i9b6aeU7xu6xBw_.size = sizeof(tySequence__JokFGfUW6i9b6aeU7xu6xBw*);
NTI__JokFGfUW6i9b6aeU7xu6xBw_.align = NIM_ALIGNOF(tySequence__JokFGfUW6i9b6aeU7xu6xBw*);
NTI__JokFGfUW6i9b6aeU7xu6xBw_.kind = 24;
NTI__JokFGfUW6i9b6aeU7xu6xBw_.base = (&NTI__2tJGcW69ahqq39a9bVJC1sqGQ_);
NTI__JokFGfUW6i9b6aeU7xu6xBw_.flags = 2;
NTI__JokFGfUW6i9b6aeU7xu6xBw_.marker = Marker_tySequence__JokFGfUW6i9b6aeU7xu6xBw;
TM__LKTmeQxNOMAggl6ESLJFSg_0[11].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[11].offset = offsetof(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ, blocks);
TM__LKTmeQxNOMAggl6ESLJFSg_0[11].typ = (&NTI__JokFGfUW6i9b6aeU7xu6xBw_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[11].name = "blocks";
TM__LKTmeQxNOMAggl6ESLJFSg_3_4[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[15];
TM__LKTmeQxNOMAggl6ESLJFSg_0[15].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[15].offset = offsetof(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ, sym);
TM__LKTmeQxNOMAggl6ESLJFSg_0[15].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[15].name = "sym";
TM__LKTmeQxNOMAggl6ESLJFSg_3_4[2] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[16];
NTI__SlmU1Ju0WFHUWkihyHMVYg_.size = sizeof(tyTuple__SlmU1Ju0WFHUWkihyHMVYg);
NTI__SlmU1Ju0WFHUWkihyHMVYg_.align = NIM_ALIGNOF(tyTuple__SlmU1Ju0WFHUWkihyHMVYg);
NTI__SlmU1Ju0WFHUWkihyHMVYg_.kind = 18;
NTI__SlmU1Ju0WFHUWkihyHMVYg_.base = 0;
NTI__SlmU1Ju0WFHUWkihyHMVYg_.flags = 3;
TM__LKTmeQxNOMAggl6ESLJFSg_5_2[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[18];
TM__LKTmeQxNOMAggl6ESLJFSg_0[18].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[18].offset = offsetof(tyTuple__SlmU1Ju0WFHUWkihyHMVYg, Field0);
TM__LKTmeQxNOMAggl6ESLJFSg_0[18].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[18].name = "Field0";
TM__LKTmeQxNOMAggl6ESLJFSg_5_2[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[19];
NTI__QOyrDzzey9cf6gDtSRPuZMQ_.size = sizeof(tyEnum_TSlotKind__QOyrDzzey9cf6gDtSRPuZMQ);
NTI__QOyrDzzey9cf6gDtSRPuZMQ_.align = NIM_ALIGNOF(tyEnum_TSlotKind__QOyrDzzey9cf6gDtSRPuZMQ);
NTI__QOyrDzzey9cf6gDtSRPuZMQ_.kind = 14;
NTI__QOyrDzzey9cf6gDtSRPuZMQ_.base = 0;
NTI__QOyrDzzey9cf6gDtSRPuZMQ_.flags = 3;
for (TM__LKTmeQxNOMAggl6ESLJFSg_8 = 0; TM__LKTmeQxNOMAggl6ESLJFSg_8 < 9; TM__LKTmeQxNOMAggl6ESLJFSg_8++) {
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_8+20].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_8+20].offset = TM__LKTmeQxNOMAggl6ESLJFSg_8;
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_8+20].name = TM__LKTmeQxNOMAggl6ESLJFSg_7[TM__LKTmeQxNOMAggl6ESLJFSg_8];
TM__LKTmeQxNOMAggl6ESLJFSg_6_9[TM__LKTmeQxNOMAggl6ESLJFSg_8] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_8+20];
}
TM__LKTmeQxNOMAggl6ESLJFSg_0[29].len = 9; TM__LKTmeQxNOMAggl6ESLJFSg_0[29].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[29].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_6_9[0];
NTI__QOyrDzzey9cf6gDtSRPuZMQ_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[29];
TM__LKTmeQxNOMAggl6ESLJFSg_0[19].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[19].offset = offsetof(tyTuple__SlmU1Ju0WFHUWkihyHMVYg, Field1);
TM__LKTmeQxNOMAggl6ESLJFSg_0[19].typ = (&NTI__QOyrDzzey9cf6gDtSRPuZMQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[19].name = "Field1";
TM__LKTmeQxNOMAggl6ESLJFSg_0[17].len = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[17].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[17].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_5_2[0];
NTI__SlmU1Ju0WFHUWkihyHMVYg_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[17];
NTI__EYsuRBqqo81SUrCUzYSAKA_.size = sizeof(tyArray__EYsuRBqqo81SUrCUzYSAKA);
NTI__EYsuRBqqo81SUrCUzYSAKA_.align = NIM_ALIGNOF(tyArray__EYsuRBqqo81SUrCUzYSAKA);
NTI__EYsuRBqqo81SUrCUzYSAKA_.kind = 16;
NTI__EYsuRBqqo81SUrCUzYSAKA_.base = (&NTI__SlmU1Ju0WFHUWkihyHMVYg_);
NTI__EYsuRBqqo81SUrCUzYSAKA_.flags = 3;
TM__LKTmeQxNOMAggl6ESLJFSg_0[16].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[16].offset = offsetof(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ, slots);
TM__LKTmeQxNOMAggl6ESLJFSg_0[16].typ = (&NTI__EYsuRBqqo81SUrCUzYSAKA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[16].name = "slots";
TM__LKTmeQxNOMAggl6ESLJFSg_3_4[3] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[30];
TM__LKTmeQxNOMAggl6ESLJFSg_0[30].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[30].offset = offsetof(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ, maxSlots);
TM__LKTmeQxNOMAggl6ESLJFSg_0[30].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[30].name = "maxSlots";
TM__LKTmeQxNOMAggl6ESLJFSg_0[10].len = 4; TM__LKTmeQxNOMAggl6ESLJFSg_0[10].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[10].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_3_4[0];
NTI__VFEBuxrDHC6kHPzc1TWaRQ_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[10];
NTI__FM7mzTFsA8pyUhXVKKO6Gw_.size = sizeof(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ*);
NTI__FM7mzTFsA8pyUhXVKKO6Gw_.align = NIM_ALIGNOF(tyObject_PProccolonObjectType___VFEBuxrDHC6kHPzc1TWaRQ*);
NTI__FM7mzTFsA8pyUhXVKKO6Gw_.kind = 22;
NTI__FM7mzTFsA8pyUhXVKKO6Gw_.base = (&NTI__VFEBuxrDHC6kHPzc1TWaRQ_);
NTI__FM7mzTFsA8pyUhXVKKO6Gw_.flags = 2;
NTI__FM7mzTFsA8pyUhXVKKO6Gw_.marker = Marker_tyRef__FM7mzTFsA8pyUhXVKKO6Gw;
TM__LKTmeQxNOMAggl6ESLJFSg_0[9].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[9].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, prc);
TM__LKTmeQxNOMAggl6ESLJFSg_0[9].typ = (&NTI__FM7mzTFsA8pyUhXVKKO6Gw_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[9].name = "prc";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[9] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[31];
TM__LKTmeQxNOMAggl6ESLJFSg_0[31].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[31].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, module);
TM__LKTmeQxNOMAggl6ESLJFSg_0[31].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[31].name = "module";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[10] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[32];
TM__LKTmeQxNOMAggl6ESLJFSg_0[32].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[32].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, callsite);
TM__LKTmeQxNOMAggl6ESLJFSg_0[32].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[32].name = "callsite";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[11] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[33];
NTI__UbrbHUpo4hYFr1DbYzJgRQ_.size = sizeof(tyEnum_TEvalMode__UbrbHUpo4hYFr1DbYzJgRQ);
NTI__UbrbHUpo4hYFr1DbYzJgRQ_.align = NIM_ALIGNOF(tyEnum_TEvalMode__UbrbHUpo4hYFr1DbYzJgRQ);
NTI__UbrbHUpo4hYFr1DbYzJgRQ_.kind = 14;
NTI__UbrbHUpo4hYFr1DbYzJgRQ_.base = 0;
NTI__UbrbHUpo4hYFr1DbYzJgRQ_.flags = 3;
for (TM__LKTmeQxNOMAggl6ESLJFSg_11 = 0; TM__LKTmeQxNOMAggl6ESLJFSg_11 < 5; TM__LKTmeQxNOMAggl6ESLJFSg_11++) {
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_11+34].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_11+34].offset = TM__LKTmeQxNOMAggl6ESLJFSg_11;
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_11+34].name = TM__LKTmeQxNOMAggl6ESLJFSg_10[TM__LKTmeQxNOMAggl6ESLJFSg_11];
TM__LKTmeQxNOMAggl6ESLJFSg_9_5[TM__LKTmeQxNOMAggl6ESLJFSg_11] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_11+34];
}
TM__LKTmeQxNOMAggl6ESLJFSg_0[39].len = 5; TM__LKTmeQxNOMAggl6ESLJFSg_0[39].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[39].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_9_5[0];
NTI__UbrbHUpo4hYFr1DbYzJgRQ_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[39];
TM__LKTmeQxNOMAggl6ESLJFSg_0[33].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[33].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, mode);
TM__LKTmeQxNOMAggl6ESLJFSg_0[33].typ = (&NTI__UbrbHUpo4hYFr1DbYzJgRQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[33].name = "mode";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[12] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[40];
NTI__JyPEhkAmDAldmLHNNrLR0A_.size = sizeof(tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A);
NTI__JyPEhkAmDAldmLHNNrLR0A_.align = NIM_ALIGNOF(tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A);
NTI__JyPEhkAmDAldmLHNNrLR0A_.kind = 14;
NTI__JyPEhkAmDAldmLHNNrLR0A_.base = 0;
NTI__JyPEhkAmDAldmLHNNrLR0A_.flags = 3;
for (TM__LKTmeQxNOMAggl6ESLJFSg_14 = 0; TM__LKTmeQxNOMAggl6ESLJFSg_14 < 2; TM__LKTmeQxNOMAggl6ESLJFSg_14++) {
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_14+41].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_14+41].offset = TM__LKTmeQxNOMAggl6ESLJFSg_14;
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_14+41].name = TM__LKTmeQxNOMAggl6ESLJFSg_13[TM__LKTmeQxNOMAggl6ESLJFSg_14];
TM__LKTmeQxNOMAggl6ESLJFSg_12_2[TM__LKTmeQxNOMAggl6ESLJFSg_14] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_14+41];
}
TM__LKTmeQxNOMAggl6ESLJFSg_0[43].len = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[43].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[43].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_12_2[0];
NTI__JyPEhkAmDAldmLHNNrLR0A_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[43];
NTI__sOguoHO9bh9ckVU25A2Jaz1A_.size = sizeof(tySet_tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A);
NTI__sOguoHO9bh9ckVU25A2Jaz1A_.align = NIM_ALIGNOF(tySet_tyEnum_TSandboxFlag__JyPEhkAmDAldmLHNNrLR0A);
NTI__sOguoHO9bh9ckVU25A2Jaz1A_.kind = 19;
NTI__sOguoHO9bh9ckVU25A2Jaz1A_.base = (&NTI__JyPEhkAmDAldmLHNNrLR0A_);
NTI__sOguoHO9bh9ckVU25A2Jaz1A_.flags = 3;
TM__LKTmeQxNOMAggl6ESLJFSg_0[44].len = 0; TM__LKTmeQxNOMAggl6ESLJFSg_0[44].kind = 0;
NTI__sOguoHO9bh9ckVU25A2Jaz1A_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[44];
TM__LKTmeQxNOMAggl6ESLJFSg_0[40].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[40].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, features);
TM__LKTmeQxNOMAggl6ESLJFSg_0[40].typ = (&NTI__sOguoHO9bh9ckVU25A2Jaz1A_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[40].name = "features";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[13] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[45];
TM__LKTmeQxNOMAggl6ESLJFSg_0[45].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[45].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, traceActive);
TM__LKTmeQxNOMAggl6ESLJFSg_0[45].typ = (&NTI__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[45].name = "traceActive";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[14] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[46];
TM__LKTmeQxNOMAggl6ESLJFSg_0[46].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[46].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, loopIterations);
TM__LKTmeQxNOMAggl6ESLJFSg_0[46].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[46].name = "loopIterations";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[15] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[47];
TM__LKTmeQxNOMAggl6ESLJFSg_0[47].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[47].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, comesFromHeuristic);
TM__LKTmeQxNOMAggl6ESLJFSg_0[47].typ = (&NTI__WGx4rAexNXnczy1Avn646Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[47].name = "comesFromHeuristic";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[16] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[48];
NTI__C1iPjdrPjiQaUrcFhIp9aGw_.size = sizeof(tyTuple__C1iPjdrPjiQaUrcFhIp9aGw);
NTI__C1iPjdrPjiQaUrcFhIp9aGw_.align = NIM_ALIGNOF(tyTuple__C1iPjdrPjiQaUrcFhIp9aGw);
NTI__C1iPjdrPjiQaUrcFhIp9aGw_.kind = 18;
NTI__C1iPjdrPjiQaUrcFhIp9aGw_.base = 0;
TM__LKTmeQxNOMAggl6ESLJFSg_15_2[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[50];
TM__LKTmeQxNOMAggl6ESLJFSg_0[50].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[50].offset = offsetof(tyTuple__C1iPjdrPjiQaUrcFhIp9aGw, Field0);
TM__LKTmeQxNOMAggl6ESLJFSg_0[50].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[50].name = "Field0";
TM__LKTmeQxNOMAggl6ESLJFSg_15_2[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[51];
NTI__5QC9cKfPJmKuW0XbCTd8ylA_.size = sizeof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__5QC9cKfPJmKuW0XbCTd8ylA_.align = NIM_ALIGNOF(tyTuple__JfHvHzMrhKkWAUvQKe0i1A);
NTI__5QC9cKfPJmKuW0XbCTd8ylA_.kind = 18;
NTI__5QC9cKfPJmKuW0XbCTd8ylA_.base = 0;
TM__LKTmeQxNOMAggl6ESLJFSg_16_2[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[53];
TM__LKTmeQxNOMAggl6ESLJFSg_0[53].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[53].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field0);
TM__LKTmeQxNOMAggl6ESLJFSg_0[53].typ = (&NTI__vr5DoT1jILTGdRlYv1OYpw_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[53].name = "Field0";
TM__LKTmeQxNOMAggl6ESLJFSg_16_2[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[54];
TM__LKTmeQxNOMAggl6ESLJFSg_0[54].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[54].offset = offsetof(tyTuple__JfHvHzMrhKkWAUvQKe0i1A, Field1);
TM__LKTmeQxNOMAggl6ESLJFSg_0[54].typ = (&NTI__HsJiUUcO9cHBdUCi0HwkSTA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[54].name = "Field1";
TM__LKTmeQxNOMAggl6ESLJFSg_0[52].len = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[52].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[52].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_16_2[0];
NTI__5QC9cKfPJmKuW0XbCTd8ylA_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[52];
TM__LKTmeQxNOMAggl6ESLJFSg_0[51].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[51].offset = offsetof(tyTuple__C1iPjdrPjiQaUrcFhIp9aGw, Field1);
TM__LKTmeQxNOMAggl6ESLJFSg_0[51].typ = (&NTI__5QC9cKfPJmKuW0XbCTd8ylA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[51].name = "Field1";
TM__LKTmeQxNOMAggl6ESLJFSg_0[49].len = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[49].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[49].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_15_2[0];
NTI__C1iPjdrPjiQaUrcFhIp9aGw_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[49];
NTI__YWbgnI9b9a4j9aDYnupShIg3A_.size = sizeof(tySequence__YWbgnI9b9a4j9aDYnupShIg3A*);
NTI__YWbgnI9b9a4j9aDYnupShIg3A_.align = NIM_ALIGNOF(tySequence__YWbgnI9b9a4j9aDYnupShIg3A*);
NTI__YWbgnI9b9a4j9aDYnupShIg3A_.kind = 24;
NTI__YWbgnI9b9a4j9aDYnupShIg3A_.base = (&NTI__C1iPjdrPjiQaUrcFhIp9aGw_);
NTI__YWbgnI9b9a4j9aDYnupShIg3A_.marker = Marker_tySequence__YWbgnI9b9a4j9aDYnupShIg3A;
TM__LKTmeQxNOMAggl6ESLJFSg_0[48].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[48].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, callbacks);
TM__LKTmeQxNOMAggl6ESLJFSg_0[48].typ = (&NTI__YWbgnI9b9a4j9aDYnupShIg3A_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[48].name = "callbacks";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[17] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[55];
TM__LKTmeQxNOMAggl6ESLJFSg_0[55].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[55].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, errorFlag);
TM__LKTmeQxNOMAggl6ESLJFSg_0[55].typ = (&NTI__77mFvmsOLKik79ci2hXkHEg_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[55].name = "errorFlag";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[18] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[56];
TM__LKTmeQxNOMAggl6ESLJFSg_0[56].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[56].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, cache);
TM__LKTmeQxNOMAggl6ESLJFSg_0[56].typ = (&NTI__lnkYNZP9asc88UfiEGjLrbA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[56].name = "cache";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[19] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[57];
TM__LKTmeQxNOMAggl6ESLJFSg_0[57].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[57].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, config);
TM__LKTmeQxNOMAggl6ESLJFSg_0[57].typ = (&NTI__a8lycfSA25OQltN3OMeBsA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[57].name = "config";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[20] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[58];
TM__LKTmeQxNOMAggl6ESLJFSg_0[58].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[58].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, graph);
TM__LKTmeQxNOMAggl6ESLJFSg_0[58].typ = (&NTI__KfdHSsl8vyUCSI9b3inBcww_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[58].name = "graph";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[21] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[59];
TM__LKTmeQxNOMAggl6ESLJFSg_0[59].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[59].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, oldErrorCount);
TM__LKTmeQxNOMAggl6ESLJFSg_0[59].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[59].name = "oldErrorCount";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[22] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[60];
NTI__X5SfC6PDEhDFna4qLF0vtg_.size = sizeof(tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg);
NTI__X5SfC6PDEhDFna4qLF0vtg_.align = NIM_ALIGNOF(tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg);
NTI__X5SfC6PDEhDFna4qLF0vtg_.kind = 18;
NTI__X5SfC6PDEhDFna4qLF0vtg_.base = 0;
NTI__X5SfC6PDEhDFna4qLF0vtg_.flags = 2;
TM__LKTmeQxNOMAggl6ESLJFSg_17_2[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[62];
TM__LKTmeQxNOMAggl6ESLJFSg_0[62].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[62].offset = offsetof(tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg, tEnter);
TM__LKTmeQxNOMAggl6ESLJFSg_0[62].typ = (&NTI__w9bl9a1ul9ctRJWiMl9cNnIMvg_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[62].name = "tEnter";
TM__LKTmeQxNOMAggl6ESLJFSg_17_2[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[63];
NTI__DYXeymOyKb0OnIuD1ihEpQ_.size = sizeof(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ);
NTI__DYXeymOyKb0OnIuD1ihEpQ_.align = NIM_ALIGNOF(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ);
NTI__DYXeymOyKb0OnIuD1ihEpQ_.kind = 18;
NTI__DYXeymOyKb0OnIuD1ihEpQ_.base = 0;
TM__LKTmeQxNOMAggl6ESLJFSg_18_5[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[65];
TM__LKTmeQxNOMAggl6ESLJFSg_0[65].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[65].offset = offsetof(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ, prc);
TM__LKTmeQxNOMAggl6ESLJFSg_0[65].typ = (&NTI__K9bspPztfoWajecnwjyHuYQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[65].name = "prc";
TM__LKTmeQxNOMAggl6ESLJFSg_18_5[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[66];
NTI__GJRDbRqzZnSsmt2gZMzKBA_.size = sizeof(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA);
NTI__GJRDbRqzZnSsmt2gZMzKBA_.align = NIM_ALIGNOF(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA);
NTI__GJRDbRqzZnSsmt2gZMzKBA_.kind = 18;
NTI__GJRDbRqzZnSsmt2gZMzKBA_.base = 0;
NTI__GJRDbRqzZnSsmt2gZMzKBA_.flags = 2;
NTI__BUH8cfx9botv2xAfmC8mnAQ_.size = sizeof(tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ);
NTI__BUH8cfx9botv2xAfmC8mnAQ_.align = NIM_ALIGNOF(tyEnum_TRegisterKind__BUH8cfx9botv2xAfmC8mnAQ);
NTI__BUH8cfx9botv2xAfmC8mnAQ_.kind = 14;
NTI__BUH8cfx9botv2xAfmC8mnAQ_.base = 0;
NTI__BUH8cfx9botv2xAfmC8mnAQ_.flags = 3;
for (TM__LKTmeQxNOMAggl6ESLJFSg_21 = 0; TM__LKTmeQxNOMAggl6ESLJFSg_21 < 6; TM__LKTmeQxNOMAggl6ESLJFSg_21++) {
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_21+68].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_21+68].offset = TM__LKTmeQxNOMAggl6ESLJFSg_21;
TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_21+68].name = TM__LKTmeQxNOMAggl6ESLJFSg_20[TM__LKTmeQxNOMAggl6ESLJFSg_21];
TM__LKTmeQxNOMAggl6ESLJFSg_19_6[TM__LKTmeQxNOMAggl6ESLJFSg_21] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[TM__LKTmeQxNOMAggl6ESLJFSg_21+68];
}
TM__LKTmeQxNOMAggl6ESLJFSg_0[74].len = 6; TM__LKTmeQxNOMAggl6ESLJFSg_0[74].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[74].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_19_6[0];
NTI__BUH8cfx9botv2xAfmC8mnAQ_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[74];
TM__LKTmeQxNOMAggl6ESLJFSg_0[67].kind = 3;
TM__LKTmeQxNOMAggl6ESLJFSg_0[67].offset = offsetof(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA, kind);
TM__LKTmeQxNOMAggl6ESLJFSg_0[67].typ = (&NTI__BUH8cfx9botv2xAfmC8mnAQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[67].name = "kind";
TM__LKTmeQxNOMAggl6ESLJFSg_0[67].sons = &NimDT___GJRDbRqzZnSsmt2gZMzKBA_kind[0];
TM__LKTmeQxNOMAggl6ESLJFSg_0[67].len = 6;
TM__LKTmeQxNOMAggl6ESLJFSg_0[75].len = 0; TM__LKTmeQxNOMAggl6ESLJFSg_0[75].kind = 2;
NimDT___GJRDbRqzZnSsmt2gZMzKBA_kind[0] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[75];
TM__LKTmeQxNOMAggl6ESLJFSg_0[76].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[76].offset = offsetof(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA, intVal);
TM__LKTmeQxNOMAggl6ESLJFSg_0[76].typ = (&NTI__Aav8dQoMlCFnZRxA0IhTHQ_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[76].name = "intVal";
NimDT___GJRDbRqzZnSsmt2gZMzKBA_kind[2] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[76];
TM__LKTmeQxNOMAggl6ESLJFSg_0[77].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[77].offset = offsetof(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA, floatVal);
TM__LKTmeQxNOMAggl6ESLJFSg_0[77].typ = (&NTI__w9bl9a1ul9ctRJWiMl9cNnIMvg_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[77].name = "floatVal";
NimDT___GJRDbRqzZnSsmt2gZMzKBA_kind[3] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[77];
TM__LKTmeQxNOMAggl6ESLJFSg_0[78].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[78].offset = offsetof(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA, node);
TM__LKTmeQxNOMAggl6ESLJFSg_0[78].typ = (&NTI__fKfcLzXYiz5jNu3NH3Tv8Q_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[78].name = "node";
NimDT___GJRDbRqzZnSsmt2gZMzKBA_kind[1] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[78];
NTI__RjjpIF1Vbh8mUcjJMFLQMA_.size = sizeof(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA*);
NTI__RjjpIF1Vbh8mUcjJMFLQMA_.align = NIM_ALIGNOF(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA*);
NTI__RjjpIF1Vbh8mUcjJMFLQMA_.kind = 21;
NTI__RjjpIF1Vbh8mUcjJMFLQMA_.base = (&NTI__GJRDbRqzZnSsmt2gZMzKBA_);
NTI__RjjpIF1Vbh8mUcjJMFLQMA_.flags = 3;
TM__LKTmeQxNOMAggl6ESLJFSg_0[79].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[79].offset = offsetof(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA, regAddr);
TM__LKTmeQxNOMAggl6ESLJFSg_0[79].typ = (&NTI__RjjpIF1Vbh8mUcjJMFLQMA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[79].name = "regAddr";
NimDT___GJRDbRqzZnSsmt2gZMzKBA_kind[4] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[79];
TM__LKTmeQxNOMAggl6ESLJFSg_0[80].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[80].offset = offsetof(tyObject_TFullReg__GJRDbRqzZnSsmt2gZMzKBA, nodeAddr);
TM__LKTmeQxNOMAggl6ESLJFSg_0[80].typ = (&NTI__uyBDtVkS7CL1Bm1j1dvmcw_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[80].name = "nodeAddr";
NimDT___GJRDbRqzZnSsmt2gZMzKBA_kind[5] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[80];
NTI__GJRDbRqzZnSsmt2gZMzKBA_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[67];
NTI__jlXqfsdfoRhiIfoVNWV0Vw_.size = sizeof(tySequence__jlXqfsdfoRhiIfoVNWV0Vw*);
NTI__jlXqfsdfoRhiIfoVNWV0Vw_.align = NIM_ALIGNOF(tySequence__jlXqfsdfoRhiIfoVNWV0Vw*);
NTI__jlXqfsdfoRhiIfoVNWV0Vw_.kind = 24;
NTI__jlXqfsdfoRhiIfoVNWV0Vw_.base = (&NTI__GJRDbRqzZnSsmt2gZMzKBA_);
NTI__jlXqfsdfoRhiIfoVNWV0Vw_.flags = 2;
NTI__jlXqfsdfoRhiIfoVNWV0Vw_.marker = Marker_tySequence__jlXqfsdfoRhiIfoVNWV0Vw;
TM__LKTmeQxNOMAggl6ESLJFSg_0[66].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[66].offset = offsetof(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ, slots);
TM__LKTmeQxNOMAggl6ESLJFSg_0[66].typ = (&NTI__jlXqfsdfoRhiIfoVNWV0Vw_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[66].name = "slots";
TM__LKTmeQxNOMAggl6ESLJFSg_18_5[2] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[81];
TM__LKTmeQxNOMAggl6ESLJFSg_0[81].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[81].offset = offsetof(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ, next);
TM__LKTmeQxNOMAggl6ESLJFSg_0[81].typ = (&NTI__tIxM6OLoE2pUc9bMTjYhjPg_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[81].name = "next";
TM__LKTmeQxNOMAggl6ESLJFSg_18_5[3] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[82];
TM__LKTmeQxNOMAggl6ESLJFSg_0[82].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[82].offset = offsetof(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ, comesFrom);
TM__LKTmeQxNOMAggl6ESLJFSg_0[82].typ = (&NTI__rR5Bzr1D5krxoo1NcNyeMA_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[82].name = "comesFrom";
TM__LKTmeQxNOMAggl6ESLJFSg_18_5[4] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[83];
TM__LKTmeQxNOMAggl6ESLJFSg_0[83].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[83].offset = offsetof(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ, safePoints);
TM__LKTmeQxNOMAggl6ESLJFSg_0[83].typ = (&NTI__qwqHTkRvwhrRyENtudHQ7g_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[83].name = "safePoints";
TM__LKTmeQxNOMAggl6ESLJFSg_0[64].len = 5; TM__LKTmeQxNOMAggl6ESLJFSg_0[64].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[64].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_18_5[0];
NTI__DYXeymOyKb0OnIuD1ihEpQ_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[64];
NTI__tIxM6OLoE2pUc9bMTjYhjPg_.size = sizeof(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ*);
NTI__tIxM6OLoE2pUc9bMTjYhjPg_.align = NIM_ALIGNOF(tyObject_TStackFrame__DYXeymOyKb0OnIuD1ihEpQ*);
NTI__tIxM6OLoE2pUc9bMTjYhjPg_.kind = 22;
NTI__tIxM6OLoE2pUc9bMTjYhjPg_.base = (&NTI__DYXeymOyKb0OnIuD1ihEpQ_);
NTI__tIxM6OLoE2pUc9bMTjYhjPg_.marker = Marker_tyRef__tIxM6OLoE2pUc9bMTjYhjPg;
TM__LKTmeQxNOMAggl6ESLJFSg_0[63].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[63].offset = offsetof(tyObject_Profiler__X5SfC6PDEhDFna4qLF0vtg, tos);
TM__LKTmeQxNOMAggl6ESLJFSg_0[63].typ = (&NTI__tIxM6OLoE2pUc9bMTjYhjPg_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[63].name = "tos";
TM__LKTmeQxNOMAggl6ESLJFSg_0[61].len = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[61].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[61].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_17_2[0];
NTI__X5SfC6PDEhDFna4qLF0vtg_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[61];
TM__LKTmeQxNOMAggl6ESLJFSg_0[60].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[60].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, profiler);
TM__LKTmeQxNOMAggl6ESLJFSg_0[60].typ = (&NTI__X5SfC6PDEhDFna4qLF0vtg_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[60].name = "profiler";
TM__LKTmeQxNOMAggl6ESLJFSg_2_24[23] = &TM__LKTmeQxNOMAggl6ESLJFSg_0[84];
TM__LKTmeQxNOMAggl6ESLJFSg_0[84].kind = 1;
TM__LKTmeQxNOMAggl6ESLJFSg_0[84].offset = offsetof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw, templInstCounter);
TM__LKTmeQxNOMAggl6ESLJFSg_0[84].typ = (&NTI__9ai78kkwqt3gikTN9cpHKUVg_);
TM__LKTmeQxNOMAggl6ESLJFSg_0[84].name = "templInstCounter";
TM__LKTmeQxNOMAggl6ESLJFSg_0[0].len = 24; TM__LKTmeQxNOMAggl6ESLJFSg_0[0].kind = 2; TM__LKTmeQxNOMAggl6ESLJFSg_0[0].sons = &TM__LKTmeQxNOMAggl6ESLJFSg_2_24[0];
NTI__S3Av1Ng7MBWGEZZBhfDYCw_.node = &TM__LKTmeQxNOMAggl6ESLJFSg_0[0];
NTI__FD9cVFUpCDGxUmwW7TEZIFQ_.size = sizeof(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*);
NTI__FD9cVFUpCDGxUmwW7TEZIFQ_.align = NIM_ALIGNOF(tyObject_TCtx__S3Av1Ng7MBWGEZZBhfDYCw*);
NTI__FD9cVFUpCDGxUmwW7TEZIFQ_.kind = 22;
NTI__FD9cVFUpCDGxUmwW7TEZIFQ_.base = (&NTI__S3Av1Ng7MBWGEZZBhfDYCw_);
NTI__FD9cVFUpCDGxUmwW7TEZIFQ_.marker = Marker_tyRef__FD9cVFUpCDGxUmwW7TEZIFQ;
}

